@@ -137,7 +137,7 @@ $lang = array_merge($lang, array(
 	'ACP_PERMISSION_MASKS'		=> 'パーミッションマスク',
 	'ACP_PERMISSION_ROLES'		=> 'パーミッションセット',
 	'ACP_PERMISSION_TRACE'		=> 'パーミッショントレース',
-	'ACP_PHP_INFO'				=> 'PHP 情報',
+	'ACP_PHP_INFO'				=> 'PHP情報',
 	'ACP_POST_SETTINGS'			=> '投稿設定',
 	'ACP_PRUNE_FORUMS'			=> 'フォーラムのプルーニング',
 	'ACP_PRUNE_USERS'			=> 'ユーザーのプルーニング',
@@ -328,6 +328,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'データベース',
 	'DATABASE_SIZE'			=> 'データベースサイズ',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> '関数のオーバーロード の値が不適切です',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> の値は 0 か 4 である必要があります。 <samp>PHP情報</samp> ページで設定値をご確認ください。',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> '透過的な文字エンコーディングフィルタ の値が不適切です',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> の値は 0 である必要があります。 <samp>PHP情報</samp> ページで設定値をご確認ください。',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP入力文字エンコーディングの自動変換 の値が不適切です',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> の値は <samp>pass</samp> である必要があります。 <samp>PHP情報</samp> ページで設定値をご確認ください。',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP出力文字エンコーディングの自動変換 の値が不適切です',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> の値は <samp>pass</samp> である必要があります。 <samp>PHP情報</samp> ページで設定値をご確認ください。',
+
 	'FILES_PER_DAY'		=> '１日あたりのファイル添付数',
 	'FORUM_STATS'		=> '掲示板の統計データ',
 
@@ -382,7 +392,7 @@ $lang = array_merge($lang, array(
 	'VIEW_INACTIVE_USERS'	=> '無効アカウント ページへ',
 
 	'WELCOME_PHPBB'			=> 'phpBB へようこそ',
-	'WRITABLE_CONFIG'		=> 'コンフィグファイル ( config.php ) のアクセス権の設定が非常に危険です。サーバの全ユーザーに対して書き込みが許可されており、誰でも修正できる状態にあります。今すぐにファイルアクセス権を 640 または少なくとも 644 に設定（<a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php）してください。',
+	'WRITABLE_CONFIG'		=> 'コンフィグファイル ( config.php ) のアクセス権の設定が非常に危険です。サーバの全ユーザーに対して書き込みが許可されており、誰でも修正できる状態にあります。今すぐにファイルアクセス権を 640 または少なくとも 644 に設定 （ <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php ） してください。',
 ));
 
 // Inactive Users
