@@ -142,7 +142,7 @@ $lang = array_merge($lang, array(
 	'DELETE_ALL'			=> '全て削除',
 	'DELETE_COOKIES'		=> '掲示板の cookie を消去する',
 	'DELETE_MARKED'			=> '削除する',
-	'DELETE_POST'			=> '削除',
+	'DELETE_POST'			=> '削除する',
 	'DELIMITER'				=> '区切り文字',
 	'DESCENDING'			=> '降順',
 	'DISABLED'				=> '無効',
@@ -160,7 +160,7 @@ $lang = array_merge($lang, array(
 	'VIEWED_COUNTS'	=> '表示数: %d 回',
 	'VIEWED_COUNT_NONE'	=> '表示数: 0 回',
 
-	'EDIT_POST'							=> '編集',
+	'EDIT_POST'							=> '編集する',
 	'EMAIL'								=> 'メール', // Short form for EMAIL_ADDRESS
 	'EMAIL_ADDRESS'						=> 'メールアドレス',
 	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'メール送信中にエラーが発生しました。<br /><strong>エラー行: %1$s</strong><br />サーバからのリスポンス: %2$s',
@@ -168,6 +168,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'メッセージを送信するには件名を入力する必要があります',
 	'ENABLED'							=> '有効',
 	'ENCLOSURE'							=> '囲み文字',
+	'ENTER_USERNAME'					=> 'ユーザー名を入力してださい',
 	'ERR_CHANGING_DIRECTORY'			=> 'FTP セッションを開始するに当たってカレントディレクトリをルートディレクトリに変更 （ CHDIR ） しようと試みましたができなかったため、プログラム処理を中断しました',
 	'ERR_CONNECTING_SERVER'				=> 'サーバ接続時にエラーが発生しました',
 	'ERR_JAB_AUTH'						=> 'Jabber サーバ認証に失敗しました',
@@ -203,6 +204,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'フォーラムルールを確認するにはこちらをクリックしてください',
 	'FROM'					=> 'from',
 	'FSOCK_DISABLED'		=> 'PHP関数 <var>fsockopen</var> が無効に設定されているかサーバからの応答がないため、クライアント/サーバ 間のソケット接続に失敗しました',
+	'FSOCK_TIMEOUT'			=> 'ネットワークストリーミングの最中にタイムアウトが発生しました',
 
 	'FTP_FSOCK_HOST'				=> 'FTP ホスト名',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'このサイトへ接続する際に必要な FTP サーバのドメインです。多くの場合、このサイトのドメインで問題ありません。',
@@ -445,11 +447,11 @@ $lang = array_merge($lang, array(
 	'POST_PCT'				=> '投稿数の割合: %.2f%%',
 	'POST_PCT_ACTIVE'		=> '投稿数の割合: %.2f%%',
 	'POST_PCT_ACTIVE_OWN'	=> '投稿数の割合: %.2f%%',
-	'POST_REPLY'			=> '返信',
+	'POST_REPLY'			=> '返信する',
 	'POST_REPORTED'			=> '通報を見るにはこちらをクリック',
 	'POST_SUBJECT'			=> '記事の件名',
 	'POST_TIME'				=> '投稿日時',
-	'POST_TOPIC'			=> 'トピック投稿',
+	'POST_TOPIC'			=> 'トピックを投稿する',
 	'POST_UNAPPROVED'		=> 'この記事は承認待ちです',
 	'PREVIEW'				=> 'プレビュー',
 	'PREVIOUS'				=> '１つ前へ',		// Used in pagination
@@ -487,7 +489,7 @@ $lang = array_merge($lang, array(
 	'REPLYING_GLOBAL_ANNOUNCE'	=> 'グローバル告知トピックに返信中',
 	'REPLYING_MESSAGE'			=> '%s の記事に返信中',
 	'REPORT_BY'					=> 'ユーザー',
-	'REPORT_POST'				=> '通報',
+	'REPORT_POST'				=> '通報する',
 	'REPORTING_POST'			=> '記事を通報中',
 	'RESEND_ACTIVATION'			=> 'アカウント有効化メールの送信',
 	'RESET'						=> 'リセット',
@@ -631,7 +633,7 @@ $lang = array_merge($lang, array(
 	'TOPIC_REVIEW'		=> 'トピックのレビュー',
 	'TOPIC_TITLE'		=> 'トピックの件名',
 	'TOPIC_UNAPPROVED'	=> 'このトピックは承認されていません',
-	'TOTAL_ATTACHMENTS'	=> '添付ファイル数',
+	'TOTAL_ATTACHMENTS'	=> '添付ファイル',
 	'TOTAL_LOG'			=> '1 件のログ',
 	'TOTAL_LOGS'		=> '%d 件のログ',
 	'TOTAL_NO_PM'		=> 'プライベートメッセージ 0 件',
@@ -640,7 +642,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_POSTS'		=> '投稿数',
 	'TOTAL_POSTS_OTHER'	=> '投稿数: <strong>%d</strong>',
 	'TOTAL_POSTS_ZERO'	=> '投稿数: <strong>0</strong>',
-	'TOPIC_REPORTED'	=> 'トピックを通報しました',
+	'TOPIC_REPORTED'	=> 'このトピックは通報されています',
 	'TOTAL_TOPICS_OTHER'=> 'トピック数: <strong>%d</strong>',
 	'TOTAL_TOPICS_ZERO'	=> 'トピック数: <strong>0</strong>',
 	'TOTAL_USERS_OTHER'	=> '登録ユーザー数: <strong>%d</strong>',
@@ -656,6 +658,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> 件の未読メッセージ',
 	'UNREAD_POST'			=> '未読記事',
 	'UNREAD_POSTS'			=> '未読記事',
+	'UNWATCH_FORUM_CONFIRM'		=> 'このフォーラムのウォッチを解除してもよろしいですか？',
+	'UNWATCH_FORUM_DETAILED'	=> 'フォーラム “%s” のウォッチを解除してもよろしいですか？',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'このトピックのウォッチを解除してもよろしいですか？',
+	'UNWATCH_TOPIC_DETAILED'	=> 'トピック “%s” のウォッチを解除してもよろしいですか？',
 	'UNWATCHED_FORUMS'			=> '選択したフォーラムのウォッチを解除しました',
 	'UNWATCHED_TOPICS'			=> '選択したトピックのウォッチを解除しました',
 	'UNWATCHED_FORUMS_TOPICS'	=> '選択したフォーラムとトピックのウォッチを解除しました',
@@ -703,7 +709,11 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'				=> 'ウェブサイト訪問',
 
 	'WARNINGS'			=> '警告',
-	'WARN_USER'			=> '警告',
+	'WARN_USER'			=> 'ユーザーに警告する',
+	'WATCH_FORUM_CONFIRM'	=> 'このフォーラムをウォッチしますか？',
+	'WATCH_FORUM_DETAILED'	=> 'フォーラム “%s” をウォッチしますか？',
+	'WATCH_TOPIC_CONFIRM'	=> 'このトピックをウォッチしますか？',
+	'WATCH_TOPIC_DETAILED'	=> 'トピック “%s” をウォッチしますか？',
 	'WELCOME_SUBJECT'	=> '%s フォーラムへようこそ',
 	'WEBSITE'			=> 'ウェブサイト',
 	'WHOIS'				=> 'Whois',
