@@ -62,7 +62,7 @@ $help = array(
 	),
 	array(
 		0 => '以前、登録したはずなのに今はログインできません！',
-		1 => '過去にユーザー登録した際に送信されたメールをお探しください。そのメールにユーザー名とパスワードが記されています (セキュリティ上の理由でパスワードは記されていない可能性があります) 。もしかしたら何らかの理由で管理人が既にアカウントを無効化しているか削除している可能性もあります。また大抵の掲示板はデータベースのサイズを少しでも減らすため、長い間投稿していないユーザーのアカウントを定期的に削除するように設定しています。もしアカウントが削除されている場合、もう一度ユーザー登録してください。そして削除されないようフォーラムに積極的に参加するようにしてください。'
+		1 => '様々な理由により管理人がアカウントを無効化または削除することがあります。また大抵の掲示板はデータベースのサイズを少しでも減らすため、長い間投稿していないユーザーのアカウントを定期的に削除するように設定しています。このようなことがあるため、お手数ですが再度ユーザー登録を行っていただき、フォーラムに積極的に参加するようにしてください。',
 	),
 	array(
 		0 => 'COPPA とは？',
@@ -154,7 +154,7 @@ $help = array(
 	),
 	array(
 		0 => '投稿画面の “セーブ” ボタンは何ですか？',
-		1 => '作成中のメッセージを保存するためのボタンです。メッセージの完成に時間がかかる場合は利用すると良いでしょう。保存されたメッセージをロード （読み込み） するには ユーザーCP へ入室してください。'
+		1 => '作成中のメッセージを保存するためのボタンです。メッセージの完成に時間がかかる場合は利用すると良いでしょう。保存されたメッセージをロード（読み込み）するには ユーザーCP へ入室してください。'
 	),
 	array(
 		0 => 'なぜ投稿した記事に承認が必要なの？',
