@@ -64,13 +64,13 @@ $lang = array_merge($lang, array(
 $lang = array_merge($lang, array(
 	'ACCOUNT_ACTIVE'				=> 'アカウントは有効化されました。ユーザー登録して頂きありがとうございます。',
 	'ACCOUNT_ACTIVE_ADMIN'			=> 'アカウントは有効化されました',
-	'ACCOUNT_ACTIVE_PROFILE'		=> 'アカウントは再有効化されました',
+	'ACCOUNT_ACTIVE_PROFILE'		=> 'アカウントは有効化されました',
 	'ACCOUNT_ADDED'					=> 'ユーザー登録して頂きありがとうございます。アカウントは作成されました。ユーザー名とパスワードを入力すればログインできます。',
 	'ACCOUNT_COPPA'					=> 'アカウントは作成されました。ログインするにはアカウントの有効化が必要です。詳細はメールをご確認ください。',
-	'ACCOUNT_EMAIL_CHANGED'			=> 'アカウントは更新されました。ログインするにはアカウントの再有効化が必要です。有効化キーは既にあなたの新しいメールアドレスに送信済みです。詳細はメールをご確認ください。',
-	'ACCOUNT_EMAIL_CHANGED_ADMIN'	=> 'アカウントは更新されました。ログインするには管理人によるアカウントの再有効化が必要です。アカウント再有効化の要請メールは既に管理人に送信済みです。あなたのアカウントが再有効化され次第、その旨の通知メッセージがあなたに送信されます。',
+	'ACCOUNT_EMAIL_CHANGED'			=> 'アカウントは更新されました。ログインするにはアカウントの有効化が必要です。有効化キーは既にあなたの新しいメールアドレスに送信済みです。詳細はメールをご確認ください。',
+	'ACCOUNT_EMAIL_CHANGED_ADMIN'	=> 'アカウントは更新されました。ログインするには管理人によるアカウントの有効化が必要です。アカウント有効化の要請メールは既に管理人に送信済みです。あなたのアカウントが有効化され次第、その旨の通知メッセージがあなたに送信されます。',
 	'ACCOUNT_INACTIVE'				=> 'アカウントは作成されました。ログインするにはアカウントの有効化が必要です。有効化キーは既にあなたのメールアドレスに送信済みです。詳細はメールをご確認ください。',
-	'ACCOUNT_INACTIVE_ADMIN'		=> 'アカウントは作成されました。ログインするには管理人によるアカウントの再有効化が必要です。アカウント再有効化の要請メールは既に管理人に送信済みです。あなたのアカウントが再有効化され次第、その旨の通知メッセージがあなたに送信されます。',
+	'ACCOUNT_INACTIVE_ADMIN'		=> 'アカウントは作成されました。ログインするには管理人によるアカウントの有効化が必要です。アカウント有効化の要請メールは既に管理人に送信済みです。あなたのアカウントが有効化され次第、その旨の通知メッセージがあなたに送信されます。',
 	'ACTIVATION_EMAIL_SENT'			=> 'アカウント有効化メールをあなたのメールアドレスへ送信しました',
 	'ACTIVATION_EMAIL_SENT_ADMIN'	=> 'アカウント有効化メールを Admin のメールアドレスへ送信しました',
 	'ADD'							=> '追加',
@@ -87,7 +87,7 @@ $lang = array_merge($lang, array(
 	'ADMIN_EMAIL'					=> '管理人からの通知をメールで受信する',
 	'AGREE'							=> '規約に同意します',
 	'ALLOW_PM'						=> 'プライベートメッセージを受信する',
-	'ALLOW_PM_EXPLAIN'				=> ' “いいえ” に設定した場合でも管理人とモデレータからの受信は拒否できない点にご注意ください',
+	'ALLOW_PM_EXPLAIN'				=> ' “いいえ” に設定しても管理人とモデレータからのメッセージは拒否できない点にご注意ください',
 	'ALREADY_ACTIVATED'				=> 'あなたのアカウントは既に有効化されています',
 	'ATTACHMENTS_EXPLAIN'			=> '添付ファイルのリストです',
 	'ATTACHMENTS_DELETED'			=> '添付ファイルの削除に成功しました',
@@ -128,13 +128,13 @@ $lang = array_merge($lang, array(
 	'CONFIRMATION'				=> '認証コードの入力',
 	'CONFIRM_CHANGES'			=> '変更の確認',
 	'CONFIRM_EMAIL'				=> 'メールアドレス （確認）',
-	'CONFIRM_EMAIL_EXPLAIN'		=> 'メールアドレスを変更している場合のみ入力してください',
+	'CONFIRM_EMAIL_EXPLAIN'		=> '変更する時だけ入力してください',
 	'CONFIRM_EXPLAIN'			=> '不正プログラムによるログインを防ぐため、ユーザー登録するには認証コードの入力が必要です。認証コードは画像に表示されています。画像が表示されない、もしくは視覚的に問題がある場合は%s管理人%sにご連絡ください。',
 	'VC_REFRESH'				=> 'リフレッシュ',
 	'VC_REFRESH_EXPLAIN'		=> 'もし認証コードを判読できない場合、"リフレッシュ" ボタンをクリックしてください',
 	
 	'CONFIRM_PASSWORD'			=> 'パスワード （確認）',
-	'CONFIRM_PASSWORD_EXPLAIN'	=> 'パスワードを変更している場合のみ入力してください',
+	'CONFIRM_PASSWORD_EXPLAIN'	=> '変更する時だけ入力してください',
 	'COPPA_BIRTHDAY'			=> 'このサイトは COPPA （児童・オンラインプライバシー保護法） に準拠しているため、登録ユーザーの年齢を確認する必要があります。ユーザー登録するにはあなたがいつ生まれたかを私達に教えてください。',
 	'COPPA_COMPLIANCE'			=> 'COPPA の準拠',
 	'COPPA_EXPLAIN'				=> '送信ボタンをクリックすればアカウントの登録は完了しますが、両親または保護者に承諾してもらうまでアカウントは有効化されません。両親または保護者のサインを記入してもらうするためのフォームを記載したメールが送信されますのでそちらをご覧ください。サイン記入済みフォームの送り先もそのメールに記載されています。',
@@ -142,7 +142,8 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> '現在の画像',
 	'CURRENT_PASSWORD'			=> '現在のパスワード',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'パスワード、メールアドレス、ユーザー名を変更するには現在のパスワードを入力する必要があります',
-	'CUR_PASSWORD_ERROR'		=> '現在のパスワードが正しくありません',
+	'CUR_PASSWORD_EMPTY'		=> '現在のパスワード が未入力です',
+	'CUR_PASSWORD_ERROR'		=> '現在のパスワード が正しくありません',
 	'CUSTOM_DATEFORMAT'			=> 'カスタム…',
 
 	'DEFAULT_ACTION'			=> 'デフォルト動作',
@@ -173,7 +174,7 @@ $lang = array_merge($lang, array(
 	'DOMAIN_NO_MX_RECORD_EMAIL'	=> '入力したメールアドレスのドメインは有効な MXレコード ではありません',
 	'DOWNLOADS'					=> 'ダウンロード',
 	'DRAFTS_DELETED'			=> '選択した下書きをすべて削除しました',
-	'DRAFTS_EXPLAIN'			=> 'ここではセーブした下書きのロード （読み込み） 、閲覧・編集、削除を行うことができます',
+	'DRAFTS_EXPLAIN'			=> 'ここではセーブした下書きのロード（読み込み）、閲覧・編集、削除を行うことができます',
 	'DRAFT_UPDATED'				=> '下書きの更新に成功しました',
 
 	'EDIT_DRAFT_EXPLAIN'		=> 'ここでは下書きの編集を行うことができます。添付ファイルと投票を下書きに含めることはできません。',
@@ -265,16 +266,18 @@ $lang = array_merge($lang, array(
 	'MESSAGE_STORED'				=> 'メッセージの送信に成功しました',
 	'MESSAGE_TO'					=> '受取人',
 	'MESSAGES_DELETED'				=> 'メッセージの削除に成功しました',
-	'MOVE_DELETED_MESSAGES_TO'		=> 'フォルダ内のメッセージを次のフォルダへ移動させる',
+	'MOVE_DELETED_MESSAGES_TO'		=> 'フォルダ内のメッセージを指定のフォルダへ移動させる',
 	'MOVE_DOWN'						=> '下へ移動',
 	'MOVE_MARKED_TO_FOLDER'			=> 'フォルダ %s へ移動する',
 	'MOVE_PM_ERROR'					=> 'メッセージを新しいフォルダに移動している最中にエラーが発生しました。全 %2d 件の内 %1d 件のメッセージの移動を完了しています。',
 	'MOVE_TO_FOLDER'				=> 'フォルダ移動',
 	'MOVE_UP'						=> '上へ移動',
 
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'メールアドレス （確認） が未入力です',
 	'NEW_EMAIL_ERROR'				=> 'メールアドレスが不一致です',
 	'NEW_FOLDER_NAME'				=> '新しいフォルダ名',
 	'NEW_PASSWORD'					=> '新しいパスワード',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'パスワード （確認） が未入力です',
 	'NEW_PASSWORD_ERROR'			=> 'パスワードが不一致です',
 	'NOTIFY_METHOD'					=> '通知方法',
 	'NOTIFY_METHOD_BOTH'			=> '両方',
@@ -475,8 +478,8 @@ $lang = array_merge($lang, array(
 	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。アルファベットと数字のみ使用できます。',
 	'USERNAME_ALPHA_SPACERS_EXPLAIN'=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。アルファベット、数字、半角スペース、記号 -+_[] のみ使用できます。',
 	'USERNAME_ASCII_EXPLAIN'		=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。ASCII文字 （半角英数字、限られた記号） のみ使用できます。特殊な記号は使用できません。',
-	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。ラテン文字と数字のみ使用できます。特殊な記号は使用できません。',
-	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。ラテン文字、数字、半角スペース、記号 -+_[] のみ使用できます。特殊な記号は使用できません。',
+	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。ラテン系文字と数字のみ使用できます。特殊な記号は使用できません。',
+	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります。ラテン系文字、数字、半角スペース、記号 -+_[] のみ使用できます。特殊な記号は使用できません。',
 	'USERNAME_CHARS_ANY_EXPLAIN'	=> 'ユーザー名は %1$d 字以上 %2$d 字以下にする必要があります',
 	'USERNAME_TAKEN_USERNAME'		=> '入力した ユーザー名 は既に使用されています。別のユーザー名を入力してください。',
 	'USERNAME_DISALLOWED_USERNAME'	=> '入力した ユーザー名 はアクセス禁止リストか言語フィルタリストに登録されています。別のユーザー名を入力してください。',
@@ -516,7 +519,7 @@ $lang = array_merge($lang, array(
 	'YOUR_WARNINGS'				=> '警告された回数',
 
 	'PM_ACTION' => array(
-		'PLACE_INTO_FOLDER'	=> '次のフォルダへ送る',
+		'PLACE_INTO_FOLDER'	=> '指定のフォルダへ送る',
 		'MARK_AS_READ'		=> '既読にする',
 		'MARK_AS_IMPORTANT'	=> '重要視する',
 		'DELETE_MESSAGE'	=> '削除する'
@@ -547,10 +550,10 @@ $lang = array_merge($lang, array(
 
 
 	'GROUPS_EXPLAIN'	=> '複数のグループに所属している場合、（管理人がデフォルトグループの変更を許可していれば） それらグループの中から１つだけデフォルトグループを選択できます。デフォルトグループとは、他のユーザーに対してあなたがどのように見えるか、例えばユーザー名の色、アバター画像、ランクなどを決定するためのグループです。（管理人が許可していれば） 他のグループに参加することもできます。参加するグループによっては、それまでアクセスできなかったフォーラムへアクセスできるようになったり使えなかった機能が使えたりするようになるでしょう。',
-	'GROUP_LEADER'		=> 'グループリーダー',
-	'GROUP_MEMBER'		=> 'グループメンバー',
-	'GROUP_PENDING'		=> '承認待ちグループ',
-	'GROUP_NONMEMBER'	=> '非メンバーグループ',
+	'GROUP_LEADER'		=> 'リーダー',
+	'GROUP_MEMBER'		=> 'メンバー',
+	'GROUP_PENDING'		=> '承認待ち',
+	'GROUP_NONMEMBER'	=> '非メンバー',
 	'GROUP_DETAILS'		=> 'グループの詳細',
 
 	'NO_LEADER'		=> 'グループなし [ リーダー ]',
